@@ -40,7 +40,11 @@ def scopes_checker(
 ) -> bool:
     """Simple scopes to scopes checker."""
 
-    return False if not scopes else len(to_set(scopes) & check_scopes) > 0
+    return (
+        True if not check_scopes or len(check_scopes) == 0 else
+        False if not scopes or len(scopes) == 0 else
+        any(True for scope in scopes if scope in check_scopes)
+    )
 
 
 def aggregates_checker(
@@ -50,9 +54,13 @@ def aggregates_checker(
 ) -> bool:
     """Checker for scopes in access aggregates."""
 
-    return False if not aggregates else any(
-        scopes_checker(check_scopes, scopes=aggregate)
-        for aggregate in aggregates
+    return (
+        True if not check_scopes or len(check_scopes) == 0 else
+        False if not aggregates or len(aggregates) == 0 else
+        any(
+            scopes_checker(check_scopes, scopes=aggregate)
+            for aggregate in aggregates
+        )
     )
 
 
