@@ -28,7 +28,7 @@ class MultiregistryHierarchyLookup:
             for registry in self.registries
         ]
 
-    @lru_cache
+    @lru_cache()
     def get_registry(self, scope: ScopeDomain, first: bool = True):
         for registry, scopes in self.descendands:
             if scope in scopes:
@@ -36,7 +36,7 @@ class MultiregistryHierarchyLookup:
 
         if first:
             self.update_descendants()
-            self.get_registry(scope, first=False)
+            return self.get_registry(scope, first=False)
 
     def __call__(self, scope: ScopeDomain, **kwargs) -> Set[ScopeDomain]:
         registry = self.get_registry(scope)
