@@ -36,6 +36,6 @@ class Aggregate(BaseAggregate):
             'to avoid id collisions with an existing database ids.'
         )
 
-        super().__init__(name=name or group_id, *args)
+        super().__init__(name=str(name or group_id), *args)
         self.group_id = group_id
         self.verbose_name = verbose_name or self.name
