@@ -17,4 +17,8 @@ def user_checker(
 ) -> bool:
     """User scopes checker."""
 
-    return user.has_perms(check_scopes, obj=obj)
+    return (
+        False if user is None else
+        True if not check_scopes or len(check_scopes) == 0 else
+        any(user.has_perm(scope, obj=obj) for scope in check_scopes)
+    )
