@@ -1,10 +1,9 @@
 from typing import List, Union
 
-from django.utils.translation import ugettext
+from px_access_scopes.utils import flatten_aggregates
 
 from ..scopes import ScopeRegistry
 from ..aggregates import Aggregate, Aggregates
-from ..utils import flatten_aggregates
 from .permissions import generate_permissions
 from .groups import generate_group
 
