@@ -5,7 +5,10 @@ from django.db import models
 from django.utils.translation import pgettext_lazy
 from px_domains import raw
 from px_domains.registry import DomainPartType, T, RegistryNestResult
-from px_access_scopes import ScopeDomain as BaseDomain, ScopeRegistry as BaseRegistry
+from px_access_scopes import (
+    ScopeDomain as BaseDomain,
+    ScopeRegistry as BaseRegistry,
+)
 
 
 __all__ = (
@@ -29,7 +32,7 @@ def get_tuple(values: EnumField) -> TVal:
     return (values + (None, None, None))[:3]
 
 
-def get_labeled(value, label = None):
+def get_labeled(value, label=None):
     if label is None:
         return value
 
@@ -54,6 +57,7 @@ class ScopeEnum(ScopeDomain, models.Choices):
     pass
 
 
+
 # FIXME:
 # Due to an strange work of django's enums auto will be a str
 # instead of object.
@@ -90,7 +94,6 @@ class ScopeRegistry(BaseRegistry):
     _auto = auto
     _labels: OrderedDict
 
-
     def __init__(self, *a, **kw):
         super().__init__(*a, **kw)
 
@@ -102,7 +105,9 @@ class ScopeRegistry(BaseRegistry):
         for member in enum:
             self._root._labels[member] = member.label
 
-    def _resolve_field_dict(self, domain: ScopeDomain, fields: EnumFields) -> EnumDefinition:
+    def _resolve_field_dict(
+        self, domain: ScopeDomain, fields: EnumFields
+    ) -> EnumDefinition:
         values = {
             key: get_labeled(
                 self._resolve_field_value(domain, key, value),
@@ -113,13 +118,17 @@ class ScopeRegistry(BaseRegistry):
 
         return values
 
-    def _resolve_choices(self, domain: ScopeDomain, definition: Type[models.Choices]) -> EnumDefinition:
+    def _resolve_choices(
+        self, domain: ScopeDomain, definition: Type[models.Choices]
+    ) -> EnumDefinition:
         return self._resolve_field_dict(domain, [
             (key, value.value, definition._value2label_map_.get(value.value))
             for key, value in definition._member_map_.items()
         ])
 
-    def _resolve_definition(self, domain: ScopeDomain, definition: object) -> EnumDefinition:
+    def _resolve_definition(
+        self, domain: ScopeDomain, definition: object
+    ) -> EnumDefinition:
         if issubclass(definition, models.Choices):
             return self._resolve_choices(domain, definition)
 
@@ -129,7 +138,9 @@ class ScopeRegistry(BaseRegistry):
         labels = self._root._labels
         ancestors = self._lookup_ancestors(domain)
 
-        return self._LabelDomain.from_definition([str(labels.get(x)) for x in ancestors])
+        return self._LabelDomain.from_definition([
+            str(labels.get(x)) for x in ancestors
+        ])
 
     def get_choices(self, domains: List[ScopeDomain]):
         empty = [(None, self.__empty__)] if hasattr(self, '__empty__') else []
